@@ -1,9 +1,8 @@
-(* $I1: Unison file synchronizer: src/fileutil.ml $ *)
-(* $I2: Last modified by zheyang on Wed, 12 Dec 2001 02:26:21 -0500 $ *)
-(* $I3: Copyright 1999-2004 (see COPYING for details) $ *)
+(* Unison file synchronizer: src/fileutil.ml *)
+(* Copyright 1999-2007 (see COPYING for details) *)
 
 (* Convert backslashes in a string to forward slashes.  Useful in Windows.   *)
-let bs2fs s0 =
+let backslashes2forwardslashes s0 =
   try
     ignore(String.index s0 '\\'); (* avoid alloc if possible *)
     let n = String.length s0 in
